"use strict";var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");Object.defineProperty(exports, "__esModule", { value: true });exports.default = void 0;var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty")); /**
 * Class for handling single RQLite data api result
 * @module api/results/data-result
 */

/**
 * A class that represents one data result from an RQLite query or execute
 * API call
 */
class DataResult {
  /**
   * The time the results query took to complete
   */


  /**
   * The last insert id
   * @type {Number}
   */


  /**
   * The rows affected
   * @type {Number}
   */


  /**
   * An array of DataResult and/or DataResultError instances
   * @type {Array<DataResult|DataResultError>}
   */


  /**
   * An object after the columns and values are mapped from
   * an RQLite response
   */


  /**
   * The data result constructor
   * @param {Array} result An API response individual result
   * @param {Array} [valuesIndex] The index to get the values from the result
   */
  constructor(result, valuesIndex) {(0, _defineProperty2.default)(this, "time", 0);(0, _defineProperty2.default)(this, "lastInsertId", void 0);(0, _defineProperty2.default)(this, "rowsAffected", void 0);(0, _defineProperty2.default)(this, "results", []);(0, _defineProperty2.default)(this, "data", {});
    if (typeof result !== 'object') {
      throw new Error('The result argument is required to be an object');
    }
    if (typeof valuesIndex !== 'undefined' && !Number.isFinite(valuesIndex)) {
      throw new Error('The valuesIndex argument is required to be a finite number when provided');
    }
    this.time = result.time;
    this.rowsAffected = result.rows_affected;
    this.lastInsertId = result.last_insert_id;
    // Map the values array to an object where columns are the properties
    if (Number.isFinite(valuesIndex)) {const
      columns = result.columns;
      const resultValues = result.values[valuesIndex];
      if (resultValues) {
        this.data = resultValues.reduce((acc, val, i) => {
          const col = columns[i];
          acc[col] = val;
          return acc;
        }, {});
      }
    }
  }

  /**
   * Return the value a property or undefined if it does not exist
   * @returns {*} The value of the property or undefined
   */
  get(property) {
    return this.data[property];
  }

  /**
   * Get the time the result took
   * @returns {Number}
   */
  getTime() {
    return this.time;
  }

  /**
   * Get the last insert id
   * @returns {Number|undefined}
   */
  getLastInsertId() {
    return this.lastInsertId;
  }

  /**
   * Get the row affected
   * @returns {Number|undefined}
   */
  getRowsAffected() {
    return this.rowsAffected;
  }

  /**
   * Get the result data as plain object
   * @returns {Object} The data as an object
   */
  toObject() {
    // Clone deep
    return JSON.parse(JSON.stringify(this.data));
  }

  /**
   * Map the data values to an array
   * @returns {Array}
   */
  toArray() {
    return Object.values(this.data);
  }

  /**
   * Map the data properites to an array
   * @returns {String[]}
   */
  toColumnsArray() {
    return Object.keys(this.data);
  }

  /**
   * Convert the result data to a JSON string
   * @returns {String} The JSON string for the data object
   */
  toString() {
    return JSON.stringify(this.data);
  }}exports.default = DataResult;module.exports = exports.default;
//# sourceMappingURL=data-result.js.map